/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.frontend.js.loader.modules.extender.npm;

import java.util.Collection;

/**
 * An object to update the {@link NPMRegistry} modules in an efficient way.
 *
 * The motivation for this interface is the need to be able to update several
 * {@link JSModule}s without triggering a cache update, which is a quite costly
 * operation.
 *
 * Note that {@link NPMRegistryUpdate}s are not thread safe.
 *
 * Also note that the update is not performed atomically, it just groups
 * operations so that just one cache update is triggered for all of them, but
 * even if {@link NPMRegistryUpdate#finish()} is not called, the updates take
 * place and will eventually be seen in the {@link NPMRegistry} as soon as it
 * triggers a cache refresh.
 *
 * @author Iván Zaera Avellón
 * @review
 */
public interface NPMRegistryUpdate {

	/**
	 * Call this method when all modules have been updated so that the
	 * {@link NPMRegistry} can refresh its caches.
	 */
	public void finish();

	public JSModule registerJSModule(
		JSPackage jsPackage, String moduleName, Collection<String> dependencies,
		String js, String map);

	public void unregisterJSModule(JSModule jsModule);

	public void updateJSModule(
		JSModule jsModule, Collection<String> dependencies, String js,
		String map);

}